Learn R Programming

Jacquard (version 1.0.2)

CalculateTheta: Calculate Relatedness Paramenters from Jacquard Coefficients tA Capitalized Title (ideally limited to 65 characters)

Description

Function CalculateTheta calculates five identifiable relatedness parameters from a list structure containing nine matrices of Jacquard coefficients.

Usage

CalculateTheta(J, ind.sub = 1:nrow(J[[1]]))

Value

A list object with four fields:

T1

The pairwise coancestry or kinship coefficients (symmetric)

T2

The pairwise inbreeding coefficients (non-symmetric)

T3

The pairwise Least one IBD out of three (symmetric)

T4

T4 (skew-symmetric)

Arguments

J

A list structure with nine matrices of pairwise Jacquard coefficients

ind.sub

Index for subsetting the individuals

Author

Jan Graffelman (jan.graffelman@upc.edu)

Details

CalculateTheta produces four matrices according to the expressions in Graffelman et al. (2024).

References

Csuros, M. (2014) Non-identifiability of identity coefficients at biallelic loci. Theoretical Population Biology 92, pp. 22-29. tools:::Rd_expr_doi("10.1016/j.tpb.2013.11.001").

Graffelman, J., Weir, B.S. and Goudet, J. (2024) Estimation of Jacquard's genetic identity coefficients with bi-allelic variants by constrained least-squares. Preprint at bioRxiv tools:::Rd_expr_doi("10.1101/2024.03.25.586682").

See Also

Jacquard.cls

Examples

Run this code
data(DeltaSimulatedPedigree)
Theta <- CalculateTheta(DeltaSimulatedPedigree)

Run the code above in your browser using DataLab