Learn R Programming

Jacquard (version 1.0.2)

DeltaPair: Extract estimates of Jacquard coefficients for a given pair

Description

Function DeltaPair extracts from the list object of all pairwise Jacquard coefficients the set of coefficients of a given pair (i,j).

Usage

DeltaPair(Delta, i, j, digits = 7)

Value

A vector with nine elements

Arguments

Delta

A list with nine matrices of pairswise coefficients.

i

Index of the first individual.

j

Index of the second individual.

digits

Number of digits to which the coefficients are rounded.

Author

Jan Graffelman (jan.graffelman@upc.edu)

See Also

PairwiseList,Jacquard.cls

Examples

Run this code
 data(DeltaSimulatedPedigree)
 DeltaPair(DeltaSimulatedPedigree,1,2)

Run the code above in your browser using DataLab