Learn R Programming

Jacquard (version 1.0.2)

PairwiseList: Create a Pairwise List of Jacquard Coefficients

Description

Function PairwiseList processes the list structure of Jacquard coefficients and converts it into to table of pairs of individuauls with their Jacquard coefficients.

Usage

PairwiseList(X, digits = 3)

Value

A matrix

Arguments

X

A list structure of nine matrices of Jacquard coefficients.

digits

Jacquard coefficients are rounded to the given number of digits.

Author

Jan Graffelman (jan.graffelman@upc.edu)

See Also

Jacquard.cls

Examples

Run this code
data(DeltaSimulatedPedigree)

ii <- 1:3

SubSet <- list(length = 9)
for (k in 1:9) {
  SubSet[[k]] <- matrix(numeric(3^2), ncol = 3)
  SubSet[[k]] <- DeltaSimulatedPedigree[[k]][ii,ii]
}

List <- PairwiseList(SubSet)

print(List)

Run the code above in your browser using DataLab