powered by
Function DeltaPair extracts from the list object of all pairwise Jacquard coefficients the set of coefficients of a given pair (i,j).
DeltaPair
DeltaPair(Delta, i, j, digits = 7)
A vector with nine elements
A list with nine matrices of pairswise coefficients.
Index of the first individual.
Index of the second individual.
Number of digits to which the coefficients are rounded.
Jan Graffelman (jan.graffelman@upc.edu)
PairwiseList,Jacquard.cls
PairwiseList
Jacquard.cls
data(DeltaSimulatedPedigree) DeltaPair(DeltaSimulatedPedigree,1,2)
Run the code above in your browser using DataLab